# requirement: Python, pip, and most recent molviewspec version are installed
# pip install molviewspec

# 3. Import MolViewSpec
import molviewspec as mvs


# 4. Instantiate a MolViewSpec builder
builder = mvs.create_builder()


# 5. Specify the source of structural data
download1 = builder.download(url='https://files.wwpdb.org/download/1oj6.cif')
download2 = builder.download(url='https://files.wwpdb.org/download/5mjd.cif')


# 6. Specify the format of the atomic coordinates file
parse1 = download1.parse(format='mmcif')
parse2 = download2.parse(format='mmcif')


# 7. Specify which assembly to generate
structure1 = parse1.assembly_structure(assembly_id='1')
structure2 = parse2.assembly_structure(assembly_id='1')


# 8. Optional: Transform coordinates
structure2 = structure2.transform(rotation=[-0.39652203922082313, 0.918022802798312, 0.002099036562725462, 0.9068461182538327, 0.39133670281585825, 0.1564790811487865, 0.14282993460796656, 0.06395090751149791, -0.9876790426086504], translation=[-17.636085896690037, 7.970761314734439, 88.54613248028247])


# 9. Create components of interest
polymer1 = structure1.component(selector='polymer')
ligand1 = structure1.component(selector='ligand')

polymer2 = structure2.component(selector='polymer')
ligand2 = structure2.component(selector='ligand')


# 10. Create representations for components
polymer_representation1 = polymer1.representation()  # default: 'cartoon'
ligand_representation1 = ligand1.representation(type='ball_and_stick')

polymer_representation2 = polymer2.representation(type='cartoon')
ligand_representation2 = ligand2.representation(type='ball_and_stick')


# 11. Optional: Adjust color of representations
polymer_representation1.color(color='#e19039')  # orange
ligand_representation1.color(color='#eec190')  # desaturated orange

polymer_representation2.color(color='#4b7fcc')  # blue
ligand_representation2.color(color='#9cb8e3')  # desaturated blue


# 12. Export the builder state
print(builder.get_state())
