# python -m venv venv
# . venv/bin/activate
# python -m pip install -r requirements.txt
# python protocol2-1h9t.py  &&  node ~/Workspace/MolStar/molstar/lib/commonjs/cli/mvs/mvs-render.js -i data/protocol2-1h9t.mvsj -o data/protocol2-1h9t.png --molj


import molviewspec as mvs


builder = mvs.create_builder()


# Load structure
structure = (builder
             .download(url='https://files.wwpdb.org/download/1h9t.cif')
             .parse(format='mmcif')
             .model_structure()
             )


# Create components using MVS annotations
protein = structure.component_from_uri(
    uri='./annotations-1h9t.cif', format='cif',
    block_header='1h9t_annotations', category_name='components',
    field_name='component', field_values='Protein', schema='chain')
dna = structure.component_from_uri(
    uri='./annotations-1h9t.cif', format='cif',
    category_name='components', field_values='DNA', schema='chain')
ions = structure.component_from_uri(
    uri='./annotations-1h9t.cif', format='cif',
    category_name='components', field_values=['Gold', 'Chloride'],
    schema='chain')


# Create representations
protein_repr = protein.representation(type='cartoon')
dna_repr = dna.representation(type='ball_and_stick')
ions_repr = ions.representation(type='surface')


# Apply coloring using MVS annotations
protein_repr.color_from_uri(
    uri='./annotations-1h9t.cif', format='cif',
    block_header='1h9t_annotations', category_name='annotations',
    field_name='color', schema='residue_range')
dna_repr.color_from_uri(
    uri='./annotations-1h9t.cif', format='cif',
    category_name='annotations', schema='residue_range')
ions_repr.color_from_uri(
    uri='./annotations-1h9t.cif', format='cif',
    category_name='annotations', schema='residue_range')


# Add labels using MVS annotations
structure.label_from_uri(
    uri='./annotations-1h9t.cif', format='cif',
    block_header='1h9t_annotations', category_name='annotations',
    field_name='label', schema='residue_range')


# Add tooltips using MVS annotations
structure.tooltip_from_uri(
    uri='./annotations-1h9t.cif', format='cif',
    block_header='1h9t_annotations', category_name='annotations',
    field_name='label', schema='residue_range')


builder.save_state(destination='protocol2.mvsj',
                   title='An example with MVS annotations', indent=2)


# Optional - pack MVS state + annotations into a MVSX file:
import zipfile
with zipfile.ZipFile('protocol2.mvsx', mode='w') as z:
    z.write('protocol2.mvsj', arcname='index.mvsj')
    z.write('annotations-1h9t.cif', arcname='annotations-1h9t.cif')
