# requirement: Python, pip, and most recent molviewspec version are installed
# pip install molviewspec

# 1. Perform common MolViewSpec actions to create empty structure
import molviewspec as mvs

builder = mvs.create_builder()
# note: updated CIF from PDBe provides explicit bond information to render nicely
download = builder.download(url='https://www.ebi.ac.uk/pdbe/entry-files/download/4hhb_updated.cif')
parse = download.parse(format='mmcif')
structure = parse.assembly_structure(assembly_id='1')


# 2. Create a custom component expression
fe_selector = mvs.ComponentExpression(label_asym_id='E', label_atom_id='FE')


# 3. Create a representation for the first heme ligand
ligand = structure.component(selector=mvs.ComponentExpression(label_asym_id='E'))
ligand.representation(type='ball_and_stick').color(color='#ffffff').color(selector=fe_selector, color='#ff4500')


# 4. Add labels and tooltips to components
fe = structure.component(selector=fe_selector)
fe.label(text='Iron Ion').tooltip(text='Additional info that appears only on mouseover')


# 5. Specify global properties: Background color
builder.canvas(background_color='#ffcf6b')


# 6. Specify global properties: Camera position
# camera to look at heme ligand, orthogonal to porphyrin group
builder.camera(target=(18, 18, 24), position=(30 , 12,  25))


# 7. Exporting this view and opening it in a compatible 3D viewer
print(builder.get_state())
